## S3 Database Backup

This module provides a database backup solution and exports to
AWS S3 storage system.

### Features

* Supports sqlite, mysql, pgsql and dblib.
* Supports compressions gzip and bzip2.
* Tracks database export history.
* Supports a large option set as found in mysqldump.
* Allows backups to be exported to AWS S3 or local filesystem.
* Supports stored procedures.
* Select which tables are included or excluded on export.
* Exports can be generated on cron interval.
* Drush command to generate database exports as well.

### Required

* AWS S3 account - (https://aws.amazon.com/s3/)
* AWS S3 Key & Secret Key

### Dependencies

This module depends upon Composer to install (it's dependencies).

* mysqldump-php library - (https://github.com/ifsnop/mysqldump-php)
* aws-sdk-php library - (https://github.com/aws/aws-sdk-php)

### Installation/Usage

* Install module like any other contrib module. Installing through composer
will pull in all required dependencies.
```bash
composer require drupal/s3_db_backup
```
* Once installed, setup configuration and AWS S3 at:
**/admin/config/s3_db_backup/settings**


* If storing or exporting to local, please setup or use private directory
instead of public.


* Now you can run an export: **/admin/config/s3_db_backup**

### AWS S3 Settings Config

AWS S3 configuration can also be pre-configured at your site settings file as
such. This will essentially override config set in module. See example below:

```php
// S3 Database Backup Settings
$settings['s3_db_backup'] = [
  's3' => [
    'status' => TRUE,
    'bucket' => 'BUCKET_NAME_GOES_HERE',
    'region' => 'us-east-1',
    'access_key' => 'ACCESS_KEY_GOES_HERE',
    'secret_key' => 'SECRET_KEY_GOES_HERE',
  ]
];
```

### Drush Commands

Once module is configured and setup. Database backups/exports can be generated
via drush command. Please keep in mind that the download links are only made
available in Drupal admin backend.

```bash
drush s3_db_backup:export
```

### Maintainers

George Anderson (geoanders)
https://www.drupal.org/u/geoanders
